Learn R Programming

decompositionLE (version 1.0.0)

us_females: Life table values for United States, Females, 1935 and 1995

Description

A subset of data from 'Life Tables for the United States Social Security Area, 1900-2080' for United States women born in 1935 and 1995.

Usage

us_females

Arguments

Format

A data frame with 19 rows and 7 columns:

Age

ordered age groups as factor type

nm1x

age specific death rate in the age group x; x + n in the initial time period ‘1935’

l1x

number of persons alive at exact age x, in the initial time period ‘1935’ expressed as decimal form and as a proportion of the starting the age group

e1x

expectation of life at exact age x, in the initial time period ‘1935’

nm2x

age specific death rate in the age group x; x + n in the latter time period ‘1995’

l2x

number of persons alive at exact age x, in the latter time period ‘1995’ expressed as decimal form and as a proportion of the starting the age group

e2x

expectation of life at exact age x, in the latter time period ‘1995’

where n = length of the age interval